[compiler-rt] r263282 - Make printf-4 more robust to strlen interception after r263177

Reid Kleckner via llvm-commits llvm-commits at lists.llvm.org
Fri Mar 11 11:11:15 PST 2016


Author: rnk
Date: Fri Mar 11 13:11:15 2016
New Revision: 263282

URL: http://llvm.org/viewvc/llvm-project?rev=263282&view=rev
Log:
Make printf-4 more robust to strlen interception after r263177

The CHECK line was matching stack-buffer-overflow from puts calling
strlen, which is not the bug the test is trying to catch.

Modified:
    compiler-rt/trunk/test/asan/TestCases/printf-4.c

Modified: compiler-rt/trunk/test/asan/TestCases/printf-4.c
URL: http://llvm.org/viewvc/llvm-project/compiler-rt/trunk/test/asan/TestCases/printf-4.c?rev=263282&r1=263281&r2=263282&view=diff
==============================================================================
--- compiler-rt/trunk/test/asan/TestCases/printf-4.c (original)
+++ compiler-rt/trunk/test/asan/TestCases/printf-4.c Fri Mar 11 13:11:15 2016
@@ -1,10 +1,8 @@
 // RUN: %clang_asan -O2 %s -o %t
-// We need replace_str=0 and replace_intrin=0 to avoid reporting errors in
-// strlen() and memcpy() called by puts().
-// RUN: %env_asan_opts=replace_str=0:replace_intrin=0:check_printf=1 not %run %t 2>&1 | FileCheck --check-prefix=CHECK-ON %s
-// RUN: %env_asan_opts=replace_str=0:replace_intrin=0 not %run %t 2>&1 | FileCheck --check-prefix=CHECK-ON %s
+// RUN: %env_asan_opts=check_printf=1 not %run %t 2>&1 | FileCheck --check-prefix=CHECK-ON %s
+// RUN: not %run %t 2>&1 | FileCheck --check-prefix=CHECK-ON %s
 
 // FIXME: printf is not intercepted on Windows yet.
 // XFAIL: win32
 
 #include <stdio.h>
@@ -14,10 +12,14 @@ int main() {
   volatile float f = 1.239;
   volatile char s[] = "34";
   volatile char buf[2];
+  puts("before sprintf");
   sprintf((char *)buf, "%c %d %.3f %s\n", c, x, f, s);
+  puts("after sprintf");
   puts((const char *)buf);
   return 0;
   // Check that size of output buffer is sanitized.
+  // CHECK-ON: before sprintf
+  // CHECK-ON-NOT: after sprintf
   // CHECK-ON: stack-buffer-overflow
   // CHECK-ON-NOT: 0 12 1.239 34
 }
@@ -1,10 +1,8 @@
 
-// FIXME: printf is not intercepted on Windows yet.
+// FIXME: sprintf is not intercepted on Windows yet.
 // XFAIL: win32
 




More information about the llvm-commits mailing list